#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-Fs8m200E5aw9Sv6zmwOan7
key:                  lsp-2.2.0.0-Fs8m200E5aw9Sv6zmwOan7
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  879bc46aa9ed19acf85b63830bb38541
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-C1AymF4DT3XLay2bWVXOq4:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-C1AymF4DT3XLay2bWVXOq4:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-C1AymF4DT3XLay2bWVXOq4:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-C1AymF4DT3XLay2bWVXOq4:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-Fs8m200E5aw9Sv6zmwOan7
depends:
    aeson-2.2.1.0-AYdtcmOjw9uLjZBMGVgJqG
    async-2.2.6-BS84yQ2zVBrDBmVQA7dIRt
    attoparsec-0.14.4-8yfReFQVnRV5DMGjEfnPOW base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-AOMElwlwr1K1qeT7AKnTrk
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    lens-5.3.4-GfJa1w4nZDpK7bNNHceulU
    lens-aeson-1.2.3-Al43xiHDZi2BFEc6BuvQpq
    lsp-types-2.0.2.0-C1AymF4DT3XLay2bWVXOq4 mtl-2.3.1
    prettyprinter-1.7.1-CrB75FqOuOiDw6pLIzh878
    random-1.2.1.3-4XXOedIFp8GEz8QIYkmry8
    row-types-1.0.1.2-2iNw5kGztTJDtdliBKE3nJ
    sorted-list-0.2.3.1-LESKqCzPjhy8Ff9W4WlqMT stm-2.5.1.0
    temporary-1.3-D34BbdjNMzr5sMMSiijrNe text-2.0.2
    text-rope-0.3-9CnqUJHDf054CqtZqQlhh2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-9wZ7uB8CqcR5TZZg4U4qth
    uuid-1.3.16-KRGj0etiZ7F1gfImF9gFb8

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

